"use client";

import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "@/components/ui/select";
import { useState } from "react";
import MonacoEditor from "../components/monaco-editor";
import TooltipButton from "../components/tooltip-button";
import { Play, RefreshCw, Save, Settings } from "lucide-react";

export default function AnswerPage({ slug }: { slug: string }) {
  const templates = [
    {
      language: "c",
      template: `/**
 * Note: The returned array must be malloced, assume caller calls free().
 */
int* twoSum(int* nums, int numsSize, int target, int* returnSize) {
    
}`,
    },
    {
      language: "java",
      template: `class Solution {
    public int[] twoSum(int[] nums, int target) {
        
    }
}`,
    },
  ];

  // 初始化当前选择的语言和模板
  const [selectedLanguage, setSelectedLanguage] = useState(
    templates[0].language
  );
  const [languageValues, setLanguageValues] = useState<{
    [key: string]: string;
  }>({});

  // 根据选择的语言更新模板
  const handleLanguageChange = (language: string) => {
    setSelectedLanguage(language);
  };

  // 获取当前语言的值，如果状态中没有，则使用模板
  const getCurrentValue = () => {
    return (
      languageValues[selectedLanguage] ||
      templates.find((t) => t.language === selectedLanguage)?.template ||
      ""
    );
  };

  // 处理编辑器内容变化
  const handleEditorChange = (value: string | undefined) => {
    if (value !== undefined) {
      setLanguageValues((prev) => ({
        ...prev,
        [selectedLanguage]: value,
      }));
    }
  };

  // 重置代码为当前语言的模板
  const handleResetCode = () => {
    const template = templates.find(
      (t) => t.language === selectedLanguage
    )?.template;
    if (template) {
      setLanguageValues((prev) => ({
        ...prev,
        [selectedLanguage]: template,
      }));
    }
  };

  // 从 templates 中提取语言作为选项
  const options = templates.map((template) => ({
    value: template.language,
    label: template.language.toUpperCase(),
  }));

  return (
    <div className="h-full flex flex-col">
      <header className="h-8 border-b p-1 flex flex-row items-center justify-between">
        <div className="flex flex-row">
          <Select value={selectedLanguage} onValueChange={handleLanguageChange}>
            <SelectTrigger className="h-6 w-[75px] border-none shadow-none px-1.5 py-0.5">
              <SelectValue placeholder={options[0].label} />
            </SelectTrigger>
            <SelectContent>
              {options.map((option) => (
                <SelectItem key={option.value} value={option.value}>
                  {option.label}
                </SelectItem>
              ))}
            </SelectContent>
          </Select>
        </div>
        <div className="flex flex-row items-center gap-2 mr-4">
          <TooltipButton
            icon={<RefreshCw className="h-4 w-auto cursor-pointer" />}
            tooltipText="重置"
            onClick={handleResetCode}
          />
          <TooltipButton
            icon={<Settings className="h-4 w-auto cursor-pointer" />}
            tooltipText="设置"
          />
          <TooltipButton
            icon={<Play className="h-4 w-auto cursor-pointer" />}
            tooltipText="运行"
          />
          <TooltipButton
            icon={<Save className="h-4 w-auto cursor-pointer" />}
            tooltipText="保存"
          />
        </div>
      </header>
      <main className="flex-grow">
        <MonacoEditor
          language={selectedLanguage}
          template={
            templates.find((t) => t.language === selectedLanguage)?.template ||
            ""
          }
          value={getCurrentValue()}
          onChange={handleEditorChange}
        />
      </main>
      <footer className="h-9 bg-muted rounded-b-lg px-3 py-2"></footer>
    </div>
  );
}
